@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef INCLUDED_GR_TRANSCENDENTAL_H
@@ -40,13 +28,32 @@ namespace blocks {
  *
  * Possible type strings: float, double, complex_float, complex_double
  *
+ * Available functions for real and complex input:
+ *
+ * - cos
+ * - sin
+ * - tan
+ * - cosh
+ * - sinh
+ * - tanh
+ * - exp
+ * - log
+ * - log10
+ * - sqrt
+ *
+ * Available functions for real input only:
+ *
+ * - acos
+ * - asin
+ * - atan
+ *
  * output[i] = trans_fcn(input[i])
  */
 class BLOCKS_API transcendental : virtual public sync_block
 {
 public:
     // gr::blocks::transcendental::sptr
-    typedef boost::shared_ptr<transcendental> sptr;
+    typedef std::shared_ptr<transcendental> sptr;
 
     static sptr make(const std::string& name, const std::string& type = "float");
 };
