@@ -4,27 +4,19 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef INCLUDED_DIGITAL_LFSR_H
 #define INCLUDED_DIGITAL_LFSR_H
 
 #include <gnuradio/digital/api.h>
+#ifndef HAVE_BUILTIN_PARITYL
+#include <volk/volk.h>
+#endif
 #include <stdint.h>
+#include <cstdint>
 #include <stdexcept>
 
 namespace gr {
@@ -37,7 +29,7 @@ namespace digital {
  *
  * \details
  * Generates a maximal length pseudo-random sequence of length
- * 2^degree-1
+ * 2^degree-1, if supplied with a primitive polynomial.
  *
  * Constructor: digital::lfsr(int mask, int seed, int reg_len);
  *
@@ -47,9 +39,9 @@ namespace digital {
  *             order bit.
  *
  *             Some common masks might be:
- *              x^4 + x^3 + x^0 = 0x19
- *              x^5 + x^3 + x^0 = 0x29
- *              x^6 + x^5 + x^0 = 0x61
+ *              x^4 + x^3 + x^0 = 0x19, K=3
+ *              x^5 + x^3 + x^0 = 0x29, K=4
+ *              x^6 + x^5 + x^0 = 0x61, K=5
  *
  * \param seed - the initialization vector placed into the
  *             register during initialization. Low order bit
@@ -90,32 +82,33 @@ namespace digital {
 class lfsr
 {
 private:
-    uint32_t d_shift_register;
-    uint32_t d_mask;
-    uint32_t d_seed;
-    uint32_t d_shift_register_length; // less than 32
-
-    static uint32_t popCount(uint32_t x)
-    {
-        uint32_t r = x - ((x >> 1) & 033333333333) - ((x >> 2) & 011111111111);
-        return ((r + (r >> 3)) & 030707070707) % 63;
-    }
+    uint64_t d_shift_register;
+    uint64_t d_mask;
+    uint64_t d_seed;
+    uint8_t d_shift_register_length; // less than 64
 
 public:
-    lfsr(uint32_t mask, uint32_t seed, uint32_t reg_len)
+    lfsr(uint64_t mask, uint64_t seed, uint8_t reg_len)
         : d_shift_register(seed),
           d_mask(mask),
           d_seed(seed),
           d_shift_register_length(reg_len)
     {
-        if (reg_len > 31)
-            throw std::invalid_argument("reg_len must be <= 31");
+        if (reg_len > 63)
+            throw std::invalid_argument("reg_len must be <= 63");
     }
 
     unsigned char next_bit()
     {
         unsigned char output = d_shift_register & 1;
-        unsigned char newbit = popCount(d_shift_register & d_mask) % 2;
+        uint64_t newbit;
+#ifdef HAVE_BUILTIN_PARITYL
+        newbit = __builtin_parityl(d_shift_register & d_mask);
+#else
+        volk_64u_popcnt(&newbit, d_shift_register & d_mask);
+        newbit %= 2;
+#endif
+
         d_shift_register =
             ((d_shift_register >> 1) | (newbit << d_shift_register_length));
         return output;
@@ -124,7 +117,13 @@ public:
     unsigned char next_bit_scramble(unsigned char input)
     {
         unsigned char output = d_shift_register & 1;
-        unsigned char newbit = (popCount(d_shift_register & d_mask) % 2) ^ (input & 1);
+        uint64_t newbit;
+#ifdef HAVE_BUILTIN_PARITYL
+        newbit = __builtin_parityl(d_shift_register & d_mask) ^ (input & 1);
+#else
+        volk_64u_popcnt(&newbit, d_shift_register & d_mask);
+        newbit = (newbit ^ input) & 1;
+#endif
         d_shift_register =
             ((d_shift_register >> 1) | (newbit << d_shift_register_length));
         return output;
@@ -132,8 +131,15 @@ public:
 
     unsigned char next_bit_descramble(unsigned char input)
     {
-        unsigned char output = (popCount(d_shift_register & d_mask) % 2) ^ (input & 1);
-        unsigned char newbit = input & 1;
+        unsigned char output;
+#ifdef HAVE_BUILTIN_PARITYL
+        output = __builtin_parityl(d_shift_register & d_mask) ^ (input & 1);
+#else
+        uint64_t _tmp;
+        volk_64u_popcnt(&_tmp, d_shift_register & d_mask);
+        output = (_tmp ^ input) & 1;
+#endif
+        uint64_t newbit = input & 1;
         d_shift_register =
             ((d_shift_register >> 1) | (newbit << d_shift_register_length));
         return output;
@@ -155,7 +161,7 @@ public:
         }
     }
 
-    int mask() const { return d_mask; }
+    uint64_t mask() const { return d_mask; }
 };
 
 } /* namespace digital */
