@@ -2,20 +2,8 @@
 /*
  * Copyright 2015 Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef INCLUDED_DTV_DVBT_BIT_INNER_DEINTERLEVER_H
@@ -47,7 +35,7 @@ namespace dtv {
 class DTV_API dvbt_bit_inner_deinterleaver : virtual public block
 {
 public:
-    typedef boost::shared_ptr<dvbt_bit_inner_deinterleaver> sptr;
+    typedef std::shared_ptr<dvbt_bit_inner_deinterleaver> sptr;
 
     /*!
      * \brief Create a Bit Inner deinterleaver
