@@ -6,13 +6,12 @@
 # Generated: Thu Aug  1 12:08:07 2013
 ##################################################
 
-from __future__ import division
-from __future__ import unicode_literals
 from gnuradio import blocks
 from gnuradio import gr
 from gnuradio.filter import firdes
 import math
 
+
 class iqbal_gen(gr.hier_block2):
 
     def __init__(self, magnitude=0, phase=0, mode=0):
@@ -49,8 +48,8 @@ class iqbal_gen(gr.hier_block2):
         '''
         gr.hier_block2.__init__(
             self, "IQ Imbalance Generator",
-            gr.io_signature(1, 1, gr.sizeof_gr_complex*1),
-            gr.io_signature(1, 1, gr.sizeof_gr_complex*1),
+            gr.io_signature(1, 1, gr.sizeof_gr_complex * 1),
+            gr.io_signature(1, 1, gr.sizeof_gr_complex * 1),
         )
 
         ##################################################
@@ -64,9 +63,12 @@ class iqbal_gen(gr.hier_block2):
         # Blocks
         ##################################################
         # Same blocks for Transmitter and Receiver
-        self.mag = blocks.multiply_const_vff((math.pow(10,magnitude/20.0), ))
-        self.sin_phase = blocks.multiply_const_vff((math.sin(phase*math.pi/180.0), ))
-        self.cos_phase = blocks.multiply_const_vff((math.cos(phase*math.pi/180.0), ))
+        self.mag = blocks.multiply_const_vff(
+            (math.pow(10, magnitude / 20.0), ))
+        self.sin_phase = blocks.multiply_const_vff(
+            (math.sin(phase * math.pi / 180.0), ))
+        self.cos_phase = blocks.multiply_const_vff(
+            (math.cos(phase * math.pi / 180.0), ))
         self.f2c = blocks.float_to_complex(1)
         self.c2f = blocks.complex_to_float(1)
         self.adder = blocks.add_vff(1)
@@ -97,7 +99,6 @@ class iqbal_gen(gr.hier_block2):
             self.connect((self.adder, 0), (self.f2c, 1))
             self.connect((self.f2c, 0), (self, 0))
 
-
     # QT sink close method reimplementation
 
     def get_magnitude(self):
@@ -105,14 +106,12 @@ class iqbal_gen(gr.hier_block2):
 
     def set_magnitude(self, magnitude):
         self.magnitude = magnitude
-        self.mag.set_k((math.pow(10,self.magnitude / 20.0), ))
+        self.mag.set_k((math.pow(10, self.magnitude / 20.0), ))
 
     def get_phase(self):
         return self.phase
 
     def set_phase(self, phase):
         self.phase = phase
-        self.sin_phase.set_k((math.sin(self.phase*math.pi/180.0), ))
-        self.cos_phase.set_k((math.cos(self.phase*math.pi/180.0), ))
-
-
+        self.sin_phase.set_k((math.sin(self.phase * math.pi / 180.0), ))
+        self.cos_phase.set_k((math.cos(self.phase * math.pi / 180.0), ))
