@@ -1,34 +1,22 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 #
 # Copyright 2009,2012,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 from gnuradio import filter
+from gnuradio.fft import window
 from gnuradio import analog
 from gnuradio import channels
-import sys, math, time
+import sys
+import math
+import time
 import numpy
 
 try:
@@ -46,11 +34,11 @@ class fmtx(gr.hier_block2):
                                 gr.io_signature(1, 1, gr.sizeof_gr_complex))
 
         fmtx = analog.nbfm_tx(audio_rate, if_rate, max_dev=5e3,
-	                      tau=75e-6, fh=0.925*if_rate/2.0)
+                              tau=75e-6, fh=0.925 * if_rate / 2.0)
 
         # Local oscillator
         lo = analog.sig_source_c(if_rate,            # sample rate
-                                 analog.GR_SIN_WAVE, # waveform type
+                                 analog.GR_SIN_WAVE,  # waveform type
                                  lo_freq,            # frequency
                                  1.0,                # amplitude
                                  0)                  # DC Offset
@@ -60,6 +48,7 @@ class fmtx(gr.hier_block2):
         self.connect(lo, (mixer, 1))
         self.connect(mixer, self)
 
+
 class fmtest(gr.top_block):
     def __init__(self):
         gr.top_block.__init__(self)
@@ -71,14 +60,16 @@ class fmtest(gr.top_block):
         self._N = 5
         chspacing = 16000
         freq = [10, 20, 30, 40, 50]
-        f_lo = [0, 1*chspacing, -1*chspacing, 2*chspacing, -2*chspacing]
+        f_lo = [0, 1 * chspacing, -1 * chspacing,
+                2 * chspacing, -2 * chspacing]
 
-        self._if_rate = 4*self._N*self._audio_rate
+        self._if_rate = 4 * self._N * self._audio_rate
 
         # Create a signal source and frequency modulate it
         self.sum = blocks.add_cc()
         for n in range(self._N):
-            sig = analog.sig_source_f(self._audio_rate, analog.GR_SIN_WAVE, freq[n], 0.5)
+            sig = analog.sig_source_f(
+                self._audio_rate, analog.GR_SIN_WAVE, freq[n], 0.5)
             fm = fmtx(f_lo[n], self._audio_rate, self._if_rate)
             self.connect(sig, fm)
             self.connect(fm, (self.sum, n))
@@ -89,7 +80,6 @@ class fmtest(gr.top_block):
 
         self.connect(self.sum, self.head, self.channel, self.snk_tx)
 
-
         # Design the channlizer
         self._M = 10
         bw = chspacing / 2.0
@@ -97,7 +87,7 @@ class fmtest(gr.top_block):
         self._chan_rate = self._if_rate / self._M
         self._taps = filter.firdes.low_pass_2(1, self._if_rate, bw, t_bw,
                                               attenuation_dB=100,
-                                              window=filter.firdes.WIN_BLACKMAN_hARRIS)
+                                              window=window.WIN_BLACKMAN_hARRIS)
         tpc = math.ceil(float(len(self._taps)) / float(self._M))
 
         print("Number of taps:     ", len(self._taps))
@@ -113,10 +103,12 @@ class fmtest(gr.top_block):
         self.squelch = list()
         self.snks = list()
         for i in range(self._M):
-            self.fmdet.append(analog.nbfm_rx(self._audio_rate, self._chan_rate))
-            self.squelch.append(analog.standard_squelch(self._audio_rate*10))
+            self.fmdet.append(analog.nbfm_rx(
+                self._audio_rate, self._chan_rate))
+            self.squelch.append(analog.standard_squelch(self._audio_rate * 10))
             self.snks.append(blocks.vector_sink_f())
-            self.connect((self.pfb, i), self.fmdet[i], self.squelch[i], self.snks[i])
+            self.connect(
+                (self.pfb, i), self.fmdet[i], self.squelch[i], self.snks[i])
 
     def num_tx_channels(self):
         return self._N
@@ -124,6 +116,7 @@ class fmtest(gr.top_block):
     def num_rx_channels(self):
         return self._M
 
+
 def main():
 
     fm = fmtest()
@@ -133,9 +126,9 @@ def main():
     tend = time.time()
 
     if 1:
-        fig1 = pylab.figure(1, figsize=(12,10), facecolor="w")
-        fig2 = pylab.figure(2, figsize=(12,10), facecolor="w")
-        fig3 = pylab.figure(3, figsize=(12,10), facecolor="w")
+        fig1 = pylab.figure(1, figsize=(12, 10), facecolor="w")
+        fig2 = pylab.figure(2, figsize=(12, 10), facecolor="w")
+        fig3 = pylab.figure(3, figsize=(12, 10), facecolor="w")
 
         Ns = 10000
         Ne = 100000
@@ -146,16 +139,16 @@ def main():
         # Plot transmitted signal
         fs = fm._if_rate
 
-        d = fm.snk_tx.data()[Ns:Ns+Ne]
+        d = fm.snk_tx.data()[Ns:Ns + Ne]
         sp1_f = fig1.add_subplot(2, 1, 1)
 
-        X,freq = sp1_f.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs,
-                           window = lambda d: d*winfunc(fftlen),
-                           visible=False)
-        X_in = 10.0*numpy.log10(abs(numpy.fft.fftshift(X)))
+        X, freq = sp1_f.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs,
+                            window=lambda d: d * winfunc(fftlen),
+                            visible=False)
+        X_in = 10.0 * numpy.log10(abs(numpy.fft.fftshift(X)))
         f_in = numpy.arange(-fs / 2.0, fs / 2.0, fs / float(X_in.size))
         p1_f = sp1_f.plot(f_in, X_in, "b")
-        sp1_f.set_xlim([min(f_in), max(f_in)+1])
+        sp1_f.set_xlim([min(f_in), max(f_in) + 1])
         sp1_f.set_ylim([-120.0, 20.0])
 
         sp1_f.set_title("Input Signal", weight="bold")
@@ -163,7 +156,7 @@ def main():
         sp1_f.set_ylabel("Power (dBW)")
 
         Ts = 1.0 / fs
-        Tmax = len(d)*Ts
+        Tmax = len(d) * Ts
 
         t_in = numpy.arange(0, Tmax, Ts)
         x_in = numpy.array(d)
@@ -187,16 +180,16 @@ def main():
             #    this is a bug, probably due to the corner cases
             d = fm.snks[i].data()[Ns:Ne]
 
-            sp2_f = fig2.add_subplot(Nrows, Ncols, 1+i)
-            X,freq = sp2_f.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs_o,
-                               window = lambda d: d*winfunc(fftlen),
-                               visible=False)
+            sp2_f = fig2.add_subplot(Nrows, Ncols, 1 + i)
+            X, freq = sp2_f.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs_o,
+                                window=lambda d: d * winfunc(fftlen),
+                                visible=False)
             #X_o = 10.0*numpy.log10(abs(numpy.fft.fftshift(X)))
-            X_o = 10.0*numpy.log10(abs(X))
+            X_o = 10.0 * numpy.log10(abs(X))
             #f_o = numpy.arange(-fs_o/2.0, fs_o/2.0, fs_o/float(X_o.size))
-            f_o = numpy.arange(0, fs_o / 2.0, fs_o/2.0/float(X_o.size))
+            f_o = numpy.arange(0, fs_o / 2.0, fs_o / 2.0 / float(X_o.size))
             p2_f = sp2_f.plot(f_o, X_o, "b")
-            sp2_f.set_xlim([min(f_o), max(f_o)+0.1])
+            sp2_f.set_xlim([min(f_o), max(f_o) + 0.1])
             sp2_f.set_ylim([-120.0, 20.0])
             sp2_f.grid(True)
 
@@ -204,22 +197,20 @@ def main():
             sp2_f.set_xlabel("Frequency (kHz)")
             sp2_f.set_ylabel("Power (dBW)")
 
-
             Ts = 1.0 / fs_o
-            Tmax = len(d)*Ts
+            Tmax = len(d) * Ts
             t_o = numpy.arange(0, Tmax, Ts)
 
             x_t = numpy.array(d)
-            sp2_t = fig3.add_subplot(Nrows, Ncols, 1+i)
+            sp2_t = fig3.add_subplot(Nrows, Ncols, 1 + i)
             p2_t = sp2_t.plot(t_o, x_t.real, "b")
             p2_t = sp2_t.plot(t_o, x_t.imag, "r")
-            sp2_t.set_xlim([min(t_o), max(t_o)+1])
+            sp2_t.set_xlim([min(t_o), max(t_o) + 1])
             sp2_t.set_ylim([-1, 1])
 
             sp2_t.set_xlabel("Time (s)")
             sp2_t.set_ylabel("Amplitude")
 
-
         pylab.show()
 
 
