@@ -1,32 +1,20 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 #
 # Copyright 2004,2007,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import audio
 from gnuradio import blocks
 from gnuradio.eng_arg import eng_float
 from argparse import ArgumentParser
 
+
 class my_top_block(gr.top_block):
 
     def __init__(self):
@@ -34,13 +22,13 @@ class my_top_block(gr.top_block):
 
         parser = ArgumentParser()
         parser.add_argument("-I", "--audio-input", default="",
-                          help="pcm input device name.  E.g., hw:0,0 or /dev/dsp")
+                            help="pcm input device name.  E.g., hw:0,0 or /dev/dsp")
         parser.add_argument("-r", "--sample-rate", type=eng_float, default=48000,
-                          help="set sample rate to RATE (%(default)r)")
+                            help="set sample rate to RATE (%(default)r)")
         parser.add_argument("-N", "--nsamples", type=eng_float,
-                          help="number of samples to collect [default=+inf]")
+                            help="number of samples to collect [default=+inf]")
         parser.add_argument('file_name', metavar='FILE-NAME',
-                          help="Output file path")
+                            help="Output file path")
 
         args = parser.parse_args()
 
