@@ -1,6 +1,5 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 
-from __future__ import unicode_literals
 import sys
 import pmt
 from gnuradio.ctrlport.GNURadioControlPortClient import GNURadioControlPortClient
@@ -8,11 +7,11 @@ from argparse import ArgumentParser
 
 parser = ArgumentParser()
 parser.add_argument("-H", "--host", default="localhost",
-                  help="Hostname to connect to (default=%(default)r)")
+                    help="Hostname to connect to (default=%(default)r)")
 parser.add_argument("-p", "--port", type=int, default=9090,
-                  help="Port of Controlport instance on host (default=%(default)r)")
+                    help="Port of Controlport instance on host (default=%(default)r)")
 parser.add_argument("-a", "--alias", default="gr uhd usrp source0",
-                  help="The UHD block's alias to control (default=%(default)r)")
+                    help="The UHD block's alias to control (default=%(default)r)")
 parser.add_argument("command", metavar="COMMAND")
 parser.add_argument("value", metavar="VALUE")
 args = parser.parse_args()
@@ -30,8 +29,8 @@ if(cmd == "antenna"):
 else:
     val = pmt.from_double(float(val))
 
-argv = [None, args.host, args.port]
-radiosys = GNURadioControlPortClient(argv=argv, rpcmethod='thrift')
+radiosys = GNURadioControlPortClient(
+    host=args.host, port=args.port, rpcmethod='thrift')
 radio = radiosys.client
 
 radio.postMessage(args.alias, port, pmt.cons(pmt.intern(cmd), val))
