@@ -1,27 +1,13 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.13
 #
 # Copyright 2008,2011,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import division
-from __future__ import unicode_literals
 from gnuradio import gr, eng_notation
 from gnuradio.eng_option import eng_option
 from optparse import OptionParser
@@ -35,25 +21,30 @@ from uhd_interface import uhd_transmitter
 
 n2s = eng_notation.num_to_str
 
+
 class bert_transmit(gr.hier_block2):
     def __init__(self, constellation, samples_per_symbol,
                  differential, excess_bw, gray_coded,
                  verbose, log):
 
         gr.hier_block2.__init__(self, "bert_transmit",
-                                gr.io_signature(0, 0, 0),                    # Output signature
-                                gr.io_signature(1, 1, gr.sizeof_gr_complex)) # Input signature
+                                # Output signature
+                                gr.io_signature(0, 0, 0),
+                                gr.io_signature(1, 1, gr.sizeof_gr_complex))  # Input signature
 
         # Create BERT data bit stream
-        self._bits = blocks.vector_source_b([1,], True)      # Infinite stream of ones
-        self._scrambler = digital.scrambler_bb(0x8A, 0x7F, 7) # CCSDS 7-bit scrambler
+        self._bits = blocks.vector_source_b(
+            [1, ], True)      # Infinite stream of ones
+        self._scrambler = digital.scrambler_bb(
+            0x8A, 0x7F, 7)  # CCSDS 7-bit scrambler
 
         self._mod = digital.generic_mod(constellation, differential,
                                         samples_per_symbol,
                                         gray_coded, excess_bw,
                                         verbose, log)
 
-        self._pack = blocks.unpacked_to_packed_bb(self._mod.bits_per_symbol(), gr.GR_MSB_FIRST)
+        self._pack = blocks.unpacked_to_packed_bb(
+            self._mod.bits_per_symbol(), gr.GR_MSB_FIRST)
 
         self.connect(self._bits, self._scrambler, self._pack, self._mod, self)
 
@@ -80,11 +71,11 @@ class tx_psk_block(gr.top_block):
             options.samples_per_symbol = self._sink._sps
 
         elif(options.to_file is not None):
-            self._sink = blocks.file_sink(gr.sizeof_gr_complex, options.to_file)
+            self._sink = blocks.file_sink(
+                gr.sizeof_gr_complex, options.to_file)
         else:
             self._sink = blocks.null_sink(gr.sizeof_gr_complex)
 
-
         self._transmitter = bert_transmit(self._modulator._constellation,
                                           options.samples_per_symbol,
                                           options.differential,
@@ -109,10 +100,11 @@ def get_options(mods):
                       help="Select modulation bit rate (default=%default)")
     parser.add_option("-S", "--samples-per-symbol", type="float", default=2,
                       help="set samples/symbol [default=%default]")
-    parser.add_option("","--to-file", default=None,
+    parser.add_option("", "--to-file", default=None,
                       help="Output file for modulated samples")
     if not parser.has_option("--verbose"):
-        parser.add_option("-v", "--verbose", action="store_true", default=False)
+        parser.add_option("-v", "--verbose",
+                          action="store_true", default=False)
     if not parser.has_option("--log"):
         parser.add_option("", "--log", action="store_true", default=False)
 
@@ -128,8 +120,9 @@ def get_options(mods):
 
     return (options, args)
 
+
 if __name__ == "__main__":
-    print ("""Warning: this example in its current shape is deprecated and
+    print("""Warning: this example in its current shape is deprecated and
             will be removed or fundamentally reworked in a coming GNU Radio
             release.""")
     mods = digital.modulation_utils.type_1_mods()
