@@ -1,24 +1,11 @@
-#!/usr/local/bin/python3.10
-from __future__ import unicode_literals
+#!/usr/local/bin/python3.13
 #
 # Copyright 2005,2006,2011 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
 from gnuradio import gr
@@ -33,6 +20,7 @@ import sys
 #                              receive path
 # /////////////////////////////////////////////////////////////////////////////
 
+
 class receive_path(gr.hier_block2):
     def __init__(self, rx_callback, options):
 
@@ -40,12 +28,13 @@ class receive_path(gr.hier_block2):
                                 gr.io_signature(1, 1, gr.sizeof_gr_complex),
                                 gr.io_signature(0, 0, 0))
 
+        # make a copy so we can destructively modify
+        options = copy.copy(options)
 
-        options = copy.copy(options)    # make a copy so we can destructively modify
-
-        self._verbose     = options.verbose
-        self._log         = options.log
-        self._rx_callback = rx_callback      # this callback is fired when there's a packet available
+        self._verbose = options.verbose
+        self._log = options.log
+        # this callback is fired when there's a packet available
+        self._rx_callback = rx_callback
 
         # receiver
         self.ofdm_rx = digital.ofdm_demod(options,
@@ -54,7 +43,7 @@ class receive_path(gr.hier_block2):
         # Carrier Sensing Blocks
         alpha = 0.001
         thresh = 30   # in dB, will have to adjust
-        self.probe = analog.probe_avg_mag_sqrd_c(thresh,alpha)
+        self.probe = analog.probe_avg_mag_sqrd_c(thresh, alpha)
 
         self.connect(self, self.ofdm_rx)
         self.connect(self.ofdm_rx, self.probe)
@@ -67,7 +56,7 @@ class receive_path(gr.hier_block2):
         """
         Return True if we think carrier is present.
         """
-        #return self.probe.level() > X
+        # return self.probe.level() > X
         return self.probe.unmuted()
 
     def carrier_threshold(self):
@@ -93,7 +82,8 @@ class receive_path(gr.hier_block2):
         normal.add_option("-W", "--bandwidth", type="eng_float",
                           default=500e3,
                           help="set symbol bandwidth [default=%default]")
-        normal.add_option("-v", "--verbose", action="store_true", default=False)
+        normal.add_option("-v", "--verbose",
+                          action="store_true", default=False)
         expert.add_option("", "--log", action="store_true", default=False,
                           help="Log all parts of flow graph to files (CAUTION: lots of data)")
 
