@@ -1,27 +1,13 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.13
 #
 # Copyright 2005,2006,2011 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 
 from gnuradio import gr
 from gnuradio import eng_notation
@@ -35,6 +21,7 @@ import sys
 #                              transmit path
 # /////////////////////////////////////////////////////////////////////////////
 
+
 class transmit_path(gr.hier_block2):
     def __init__(self, options):
         '''
@@ -45,10 +32,11 @@ class transmit_path(gr.hier_block2):
                                 gr.io_signature(0, 0, 0),
                                 gr.io_signature(1, 1, gr.sizeof_gr_complex))
 
-        options = copy.copy(options)    # make a copy so we can destructively modify
+        # make a copy so we can destructively modify
+        options = copy.copy(options)
 
-        self._verbose      = options.verbose      # turn verbose mode on/off
-        self._tx_amplitude = options.tx_amplitude # digital amp sent to radio
+        self._verbose = options.verbose      # turn verbose mode on/off
+        self._tx_amplitude = options.tx_amplitude  # digital amp sent to radio
 
         self.ofdm_tx = digital.ofdm_mod(options,
                                         msgq_limit=4,
@@ -102,4 +90,3 @@ class transmit_path(gr.hier_block2):
         Prints information about the transmit path
         """
         print("Tx amplitude     %s" % (self._tx_amplitude))
-
