@@ -1,31 +1,18 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.12
 #
 # Copyright 2007 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 
 from optparse import OptionParser
 import sys
 
+
 def main():
     parser = OptionParser()
     parser.add_option("-f", "--file", default=None,
@@ -47,7 +34,7 @@ def main():
     for ch in f.read():
         x = ord(ch)
         bytes = bytes + 1
-        for i in range(7,-1,-1):
+        for i in range(7, -1, -1):
             bits = bits + 1
             t = (x >> i) & 0x1
             if t == current:
@@ -56,29 +43,30 @@ def main():
                 if count > 0:
                     if len(runs) < count:
                         for j in range(count - len(runs)):
-                            runs.append(0);
-                    runs[count-1] = runs[count-1] + 1
+                            runs.append(0)
+                    runs[count - 1] = runs[count - 1] + 1
 
-                current = 1-current;
+                current = 1 - current
                 count = 1
 
     # Deal with last run at EOF
     if len(runs) < count and count > 0:
         for j in range(count - len(runs)):
-            runs.append(0);
-    runs[count-1] = runs[count-1] + 1
+            runs.append(0)
+    runs[count - 1] = runs[count - 1] + 1
 
     chk = 0
     print("Bytes read: ", bytes)
     print("Bits read:  ", bits)
     print()
     for i in range(len(runs)):
-        chk = chk + runs[i]*(i+1)
-        print("Runs of length", i+1, ":", runs[i])
+        chk = chk + runs[i] * (i + 1)
+        print("Runs of length", i + 1, ":", runs[i])
     print()
     print("Sum of runs:", chk, "bits")
     print()
     print("Maximum run length is", len(runs), "bits")
 
+
 if __name__ == "__main__":
     main()
