@@ -1,32 +1,19 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.12
 #
 # Copyright 2009,2012,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 from gnuradio import filter
-import sys, time
+from gnuradio.fft import window
+import sys
+import time
 import numpy
 
 try:
@@ -40,9 +27,11 @@ try:
     from matplotlib import pyplot
     from matplotlib import pyplot as mlab
 except ImportError:
-    sys.stderr.write("Error: Program requires matplotlib (see: matplotlib.sourceforge.net).\n")
+    sys.stderr.write(
+        "Error: Program requires matplotlib (see: matplotlib.sourceforge.net).\n")
     sys.exit(1)
 
+
 class pfb_top_block(gr.top_block):
     def __init__(self):
         gr.top_block.__init__(self)
@@ -55,7 +44,7 @@ class pfb_top_block(gr.top_block):
         self._taps = filter.firdes.low_pass_2(1, self._fs,
                                               200, 150,
                                               attenuation_dB=120,
-                                              window=filter.firdes.WIN_BLACKMAN_hARRIS)
+                                              window=window.WIN_BLACKMAN_hARRIS)
 
         # Calculate the number of taps per channel for our own information
         tpc = numpy.ceil(float(len(self._taps)) / float(self._decim))
@@ -70,8 +59,9 @@ class pfb_top_block(gr.top_block):
         self.add = blocks.add_cc()
         freqs = [10, 20, 2040]
         for i in range(len(freqs)):
-            self.signals.append(analog.sig_source_c(self._fs, analog.GR_SIN_WAVE, freqs[i], 1))
-            self.connect(self.signals[i], (self.add,i))
+            self.signals.append(analog.sig_source_c(
+                self._fs, analog.GR_SIN_WAVE, freqs[i], 1))
+            self.connect(self.signals[i], (self.add, i))
 
         self.head = blocks.head(gr.sizeof_gr_complex, self._N)
 
@@ -101,8 +91,8 @@ def main():
     print("Run time: %f" % (tend - tstart))
 
     if 1:
-        fig1 = pyplot.figure(1, figsize=(16,9))
-        fig2 = pyplot.figure(2, figsize=(16,9))
+        fig1 = pyplot.figure(1, figsize=(16, 9))
+        fig2 = pyplot.figure(2, figsize=(16, 9))
 
         Ns = 10000
         Ne = 10000
@@ -113,16 +103,16 @@ def main():
 
         # Plot the input to the decimator
 
-        d = tb.snk_i.data()[Ns:Ns+Ne]
+        d = tb.snk_i.data()[Ns:Ns + Ne]
         sp1_f = fig1.add_subplot(2, 1, 1)
 
-        X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs,
-                          window = lambda d: d*winfunc(fftlen),
-                          scale_by_freq=True)
-        X_in = 10.0*numpy.log10(abs(numpy.fft.fftshift(X)))
+        X, freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs,
+                           window=lambda d: d * winfunc(fftlen),
+                           scale_by_freq=True)
+        X_in = 10.0 * numpy.log10(abs(numpy.fft.fftshift(X)))
         f_in = numpy.arange(-fs / 2.0, fs / 2.0, fs / float(X_in.size))
         p1_f = sp1_f.plot(f_in, X_in, "b")
-        sp1_f.set_xlim([min(f_in), max(f_in)+1])
+        sp1_f.set_xlim([min(f_in), max(f_in) + 1])
         sp1_f.set_ylim([-200.0, 50.0])
 
         sp1_f.set_title("Input Signal", weight="bold")
@@ -130,40 +120,38 @@ def main():
         sp1_f.set_ylabel("Power (dBW)")
 
         Ts = 1.0 / fs
-        Tmax = len(d)*Ts
+        Tmax = len(d) * Ts
 
         t_in = numpy.arange(0, Tmax, Ts)
         x_in = numpy.array(d)
         sp1_t = fig1.add_subplot(2, 1, 2)
         p1_t = sp1_t.plot(t_in, x_in.real, "b")
         p1_t = sp1_t.plot(t_in, x_in.imag, "r")
-        sp1_t.set_ylim([-tb._decim*1.1, tb._decim*1.1])
+        sp1_t.set_ylim([-tb._decim * 1.1, tb._decim * 1.1])
 
         sp1_t.set_xlabel("Time (s)")
         sp1_t.set_ylabel("Amplitude")
 
-
         # Plot the output of the decimator
         fs_o = tb._fs / tb._decim
 
         sp2_f = fig2.add_subplot(2, 1, 1)
-        d = tb.snk.data()[Ns:Ns+Ne]
-        X,freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs_o,
-                          window = lambda d: d*winfunc(fftlen),
-                          scale_by_freq=True)
-        X_o = 10.0*numpy.log10(abs(numpy.fft.fftshift(X)))
+        d = tb.snk.data()[Ns:Ns + Ne]
+        X, freq = mlab.psd(d, NFFT=fftlen, noverlap=fftlen / 4, Fs=fs_o,
+                           window=lambda d: d * winfunc(fftlen),
+                           scale_by_freq=True)
+        X_o = 10.0 * numpy.log10(abs(numpy.fft.fftshift(X)))
         f_o = numpy.arange(-fs_o / 2.0, fs_o / 2.0, fs_o / float(X_o.size))
         p2_f = sp2_f.plot(f_o, X_o, "b")
-        sp2_f.set_xlim([min(f_o), max(f_o)+1])
+        sp2_f.set_xlim([min(f_o), max(f_o) + 1])
         sp2_f.set_ylim([-200.0, 50.0])
 
         sp2_f.set_title("PFB Decimated Signal", weight="bold")
         sp2_f.set_xlabel("Frequency (Hz)")
         sp2_f.set_ylabel("Power (dBW)")
 
-
         Ts_o = 1.0 / fs_o
-        Tmax_o = len(d)*Ts_o
+        Tmax_o = len(d) * Ts_o
 
         x_o = numpy.array(d)
         t_o = numpy.arange(0, Tmax_o, Ts_o)
@@ -183,4 +171,3 @@ if __name__ == "__main__":
         main()
     except KeyboardInterrupt:
         pass
-
