@@ -1,28 +1,13 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.12
 #
 # Copyright 2010,2012,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import filter
 from gnuradio import blocks
@@ -38,9 +23,11 @@ except ImportError:
 try:
     from matplotlib import pyplot
 except ImportError:
-    sys.stderr.write("Error: Program requires matplotlib (see: matplotlib.sourceforge.net).\n")
+    sys.stderr.write(
+        "Error: Program requires matplotlib (see: matplotlib.sourceforge.net).\n")
     sys.exit(1)
 
+
 def main():
     N = 1000000
     fs = 8000
@@ -54,7 +41,7 @@ def main():
         sigs.append(s)
 
     taps = filter.firdes.low_pass_2(len(freqs), fs,
-                                    fs/float(nchans)/2, 100, 100)
+                                    fs / float(nchans) / 2, 100, 100)
     print("Num. Taps = %d (taps per filter = %d)" % (len(taps),
                                                      len(taps) / nchans))
     filtbank = filter.pfb_synthesizer_ccf(nchans, taps)
@@ -65,26 +52,27 @@ def main():
     tb = gr.top_block()
     tb.connect(filtbank, head, snk)
 
-    for i,si in enumerate(sigs):
+    for i, si in enumerate(sigs):
         tb.connect(si, (filtbank, i))
 
     tb.run()
 
     if 1:
         f1 = pyplot.figure(1)
-        s1 = f1.add_subplot(1,1,1)
+        s1 = f1.add_subplot(1, 1, 1)
         s1.plot(snk.data()[1000:])
 
         fftlen = 2048
         f2 = pyplot.figure(2)
-        s2 = f2.add_subplot(1,1,1)
+        s2 = f2.add_subplot(1, 1, 1)
         winfunc = numpy.blackman
         s2.psd(snk.data()[10000:], NFFT=fftlen,
-               Fs = nchans*fs,
+               Fs=nchans * fs,
                noverlap=fftlen / 4,
-               window = lambda d: d*winfunc(fftlen))
+               window=lambda d: d * winfunc(fftlen))
 
         pyplot.show()
 
+
 if __name__ == "__main__":
     main()
