@@ -1,11 +1,9 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.12
 ##################################################
 # Gnuradio Python Flow Graph
 # Title: Affinity Set Test
 ##################################################
 
-from __future__ import print_function
-from __future__ import unicode_literals
 from gnuradio import eng_notation
 from gnuradio import gr
 from gnuradio import blocks
@@ -15,6 +13,7 @@ from gnuradio.filter import firdes
 from argparse import ArgumentParser
 import sys
 
+
 class affinity_set(gr.top_block):
 
     def __init__(self):
@@ -29,19 +28,23 @@ class affinity_set(gr.top_block):
         # Blocks
         ##################################################
         vec_len = 1
-        self.blocks_throttle_0 = blocks.throttle(gr.sizeof_gr_complex*vec_len, samp_rate)
-        self.blocks_null_source_0 = blocks.null_source(gr.sizeof_gr_complex*vec_len)
-        self.blocks_null_sink_0 = blocks.null_sink(gr.sizeof_gr_complex*vec_len)
-        self.filter_filt_0 = filter.fir_filter_ccc(1, 40000*[0.2+0.3j,])
-        self.filter_filt_1 = filter.fir_filter_ccc(1, 40000*[0.2+0.3j,])
+        self.blocks_throttle_0 = blocks.throttle(
+            gr.sizeof_gr_complex * vec_len, samp_rate)
+        self.blocks_null_source_0 = blocks.null_source(
+            gr.sizeof_gr_complex * vec_len)
+        self.blocks_null_sink_0 = blocks.null_sink(
+            gr.sizeof_gr_complex * vec_len)
+        self.filter_filt_0 = filter.fir_filter_ccc(1, 40000 * [0.2 + 0.3j, ])
+        self.filter_filt_1 = filter.fir_filter_ccc(1, 40000 * [0.2 + 0.3j, ])
 
-        self.filter_filt_0.set_processor_affinity([0,])
-        self.filter_filt_1.set_processor_affinity([0,1])
+        self.filter_filt_0.set_processor_affinity([0, ])
+        self.filter_filt_1.set_processor_affinity([0, 1])
 
         ##################################################
         # Connections
         ##################################################
-        self.connect((self.blocks_null_source_0, 0), (self.blocks_throttle_0, 0))
+        self.connect((self.blocks_null_source_0, 0),
+                     (self.blocks_throttle_0, 0))
         self.connect((self.blocks_throttle_0, 0), (self.filter_filt_0, 0))
         self.connect((self.filter_filt_0, 0), (self.filter_filt_1, 0))
         self.connect((self.filter_filt_1, 0), (self.blocks_null_sink_0, 0))
@@ -52,6 +55,7 @@ class affinity_set(gr.top_block):
     def set_samp_rate(self, samp_rate):
         self.samp_rate = samp_rate
 
+
 if __name__ == '__main__':
     parser = ArgumentParser()
     args = parser.parse_args()
@@ -71,4 +75,4 @@ if __name__ == '__main__':
             except ValueError:
                 print("Invalid number")
             else:
-                tb.filter_filt_0.set_processor_affinity([n,])
+                tb.filter_filt_0.set_processor_affinity([n, ])
