@@ -1,29 +1,17 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 #
 # Copyright 2008 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
 Reads output from run_synthetic.py and runs gnuplot showing
 GFLOPS as f(npipes, nstages)
 """
-from __future__ import unicode_literals
 
 import re
 import sys
@@ -59,9 +47,11 @@ def parse_file(input_filename, output):
 
 
 def handle_file(input_filename):
-    cmd_file = tempfile.NamedTemporaryFile(mode='w+', prefix='pf', suffix='.cmd')
+    cmd_file = tempfile.NamedTemporaryFile(
+        mode='w+', prefix='pf', suffix='.cmd')
     cmd_file_name = cmd_file.name
-    data_file = tempfile.NamedTemporaryFile(mode='w+', prefix='pf', suffix='.dat')
+    data_file = tempfile.NamedTemporaryFile(
+        mode='w+', prefix='pf', suffix='.dat')
     data_file_name = data_file.name
     desc = parse_file(input_filename, data_file)
     if len(desc) > 0:
@@ -80,8 +70,8 @@ def handle_file(input_filename):
 
     os.system("gnuplot " + cmd_file_name + " -")
 
-    #sys.stdout.write(open(cmd_file_name,'r').read())
-    #sys.stdout.write(open(data_file_name,'r').read())
+    # sys.stdout.write(open(cmd_file_name,'r').read())
+    # sys.stdout.write(open(data_file_name,'r').read())
 
 
 def main():
