@@ -1,48 +1,37 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 #
 # Copyright 2006,2010,2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 from argparse import ArgumentParser
 
+
 class vector_source(gr.top_block):
     def __init__(self, host, port, pkt_size, eof):
         gr.top_block.__init__(self, "vector_source")
-        data = [i*0.01 for i in range(1000)]
+        data = [i * 0.01 for i in range(1000)]
         vec = blocks.vector_source_f(data, True)
         udp = blocks.udp_sink(gr.sizeof_float, host, port, pkt_size, eof=eof)
         self.connect(vec, udp)
 
+
 if __name__ == '__main__':
     parser = ArgumentParser()
     parser.add_argument("--host", default="127.0.0.1",
-                      help="Remote host name (domain name or IP address")
+                        help="Remote host name (domain name or IP address")
     parser.add_argument("--port", type=int, default=65500,
-                      help="port number to connect to")
+                        help="port number to connect to")
     parser.add_argument("--packet-size", type=int, default=1471,
-                      help="packet size.")
+                        help="packet size.")
     parser.add_argument("--no-eof", action="store_true", default=False,
-                      help="don't send EOF on disconnect")
+                        help="don't send EOF on disconnect")
     args = parser.parse_args()
 # Create an instance of a hierarchical block
     top_block = vector_source(args.host, args.port, args.packet_size,
@@ -54,4 +43,3 @@ if __name__ == '__main__':
     except KeyboardInterrupt:
         # Ctrl-C exits
         pass
-
