@@ -1,28 +1,15 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.12
 #
 # Copyright 2011,2012,2015 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 from gnuradio import gr, filter
+from gnuradio.fft import window
 from gnuradio import blocks
 import sys
 
@@ -46,17 +33,20 @@ except ImportError:
     sys.stderr.write("Error: Program requires gr-channels.\n")
     sys.exit(1)
 
+
 class dialog_box(QtWidgets.QWidget):
     def __init__(self, display, control):
         QtWidgets.QWidget.__init__(self, None)
         self.setWindowTitle('PyQt Test GUI')
 
-        self.boxlayout = QtWidgets.QBoxLayout(QtWidgets.QBoxLayout.LeftToRight, self)
+        self.boxlayout = QtWidgets.QBoxLayout(
+            QtWidgets.QBoxLayout.LeftToRight, self)
         self.boxlayout.addWidget(display, 1)
         self.boxlayout.addWidget(control)
 
         self.resize(800, 500)
 
+
 class control_box(QtWidgets.QWidget):
     def __init__(self, parent=None):
         QtWidgets.QWidget.__init__(self, parent)
@@ -78,14 +68,12 @@ class control_box(QtWidgets.QWidget):
         self.layout.addRow("Signal 1 Amplitude:", self.amp1Edit)
         self.amp1Edit.editingFinished.connect(self.amp1EditText)
 
-
         # Control the second signal
         self.freq2Edit = QtWidgets.QLineEdit(self)
         self.freq2Edit.setMinimumWidth(100)
         self.layout.addRow("Signal 2 Frequency:", self.freq2Edit)
         self.freq2Edit.editingFinished.connect(self.freq2EditText)
 
-
         self.amp2Edit = QtWidgets.QLineEdit(self)
         self.amp2Edit.setMinimumWidth(100)
         self.layout.addRow("Signal 2 Amplitude:", self.amp2Edit)
@@ -121,7 +109,6 @@ class control_box(QtWidgets.QWidget):
         except ValueError:
             print("Bad amplitude value entered")
 
-
     def freq2EditText(self):
         try:
             newfreq = float(self.freq2Edit.text())
@@ -155,24 +142,24 @@ class my_top_block(gr.top_block):
 
         src1 = analog.sig_source_c(Rs, analog.GR_SIN_WAVE, f1, 0.1, 0)
         src2 = analog.sig_source_c(Rs, analog.GR_SIN_WAVE, f2, 0.1, 0)
-        src  = blocks.add_cc()
+        src = blocks.add_cc()
         channel = channels.channel_model(0.001)
-        thr = blocks.throttle(gr.sizeof_gr_complex, 100*fftsize)
-        self.snk1 = qtgui.sink_c(fftsize, filter.firdes.WIN_BLACKMAN_hARRIS,
+        thr = blocks.throttle(gr.sizeof_gr_complex, 100 * fftsize)
+        self.snk1 = qtgui.sink_c(fftsize, window.WIN_BLACKMAN_hARRIS,
                                  0, Rs,
                                  "Complex Signal Example",
-                                 True, True, True, False)
+                                 True, True, True, False, None)
 
-        self.connect(src1, (src,0))
-        self.connect(src2, (src,1))
-        self.connect(src,  channel, thr, self.snk1)
+        self.connect(src1, (src, 0))
+        self.connect(src2, (src, 1))
+        self.connect(src, channel, thr, self.snk1)
 
         self.ctrl_win = control_box()
         self.ctrl_win.attach_signal1(src1)
         self.ctrl_win.attach_signal2(src2)
 
         # Get the reference pointer to the SpectrumDisplayForm QWidget
-        pyQt  = self.snk1.pyqwidget()
+        pyQt = self.snk1.qwidget()
 
         # Wrap the pointer as a PyQt SIP object
         # This can now be manipulated as a PyQt5.QtWidgets.QWidget
@@ -182,8 +169,9 @@ class my_top_block(gr.top_block):
 
         self.main_box.show()
 
+
 if __name__ == "__main__":
-    tb = my_top_block();
+    tb = my_top_block()
     tb.start()
     tb.qapp.exec_()
     tb.stop()
