@@ -1,27 +1,13 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.13
 #
 # Copyright 2013,2015 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 import sys
@@ -40,17 +26,20 @@ except ImportError:
     sys.stderr.write("Error: Program requires gr-analog.\n")
     sys.exit(1)
 
+
 class dialog_box(QtWidgets.QWidget):
     def __init__(self, display, control):
         QtWidgets.QWidget.__init__(self, None)
         self.setWindowTitle('PyQt Test GUI')
 
-        self.boxlayout = QtWidgets.QBoxLayout(QtWidgets.QBoxLayout.LeftToRight, self)
+        self.boxlayout = QtWidgets.QBoxLayout(
+            QtWidgets.QBoxLayout.LeftToRight, self)
         self.boxlayout.addWidget(display, 1)
         self.boxlayout.addWidget(control)
 
         self.resize(800, 500)
 
+
 class control_box(QtWidgets.QWidget):
     def __init__(self, snk, parent=None):
         QtWidgets.QWidget.__init__(self, parent)
@@ -73,7 +62,6 @@ class control_box(QtWidgets.QWidget):
         self.layout.addRow("Sine Amplitude:", self.amp1Edit)
         self.amp1Edit.editingFinished.connect(self.amp1EditText)
 
-
         # Control the second signal
         self.amp2Edit = QtWidgets.QLineEdit(self)
         self.amp2Edit.setMinimumWidth(100)
@@ -105,7 +93,6 @@ class control_box(QtWidgets.QWidget):
 
         self.quit.clicked.connect(QtWidgets.qApp.quit)
 
-
     def attach_signal1(self, signal):
         self.signal1 = signal
         self.freq1Edit.setText(("{0}").format(self.signal1.frequency()))
@@ -163,14 +150,14 @@ class my_top_block(gr.top_block):
 
         src1 = analog.sig_source_f(Rs, analog.GR_SIN_WAVE, f1, 0, 0)
         src2 = analog.noise_source_f(analog.GR_GAUSSIAN, 1)
-        src  = blocks.add_ff()
-        thr = blocks.throttle(gr.sizeof_float, 100*npts)
+        src = blocks.add_ff()
+        thr = blocks.throttle(gr.sizeof_float, 100 * npts)
         self.snk1 = qtgui.histogram_sink_f(npts, 200, -5, 5,
-                                           "Histogram")
+                                           "Histogram", 1, None)
         self.snk1.disable_legend()
 
-        self.connect(src1, (src,0))
-        self.connect(src2, (src,1))
+        self.connect(src1, (src, 0))
+        self.connect(src2, (src, 1))
         self.connect(src, thr, self.snk1)
 
         self.ctrl_win = control_box(self.snk1)
@@ -178,18 +165,19 @@ class my_top_block(gr.top_block):
         self.ctrl_win.attach_signal2(src2)
 
         # Get the reference pointer to the SpectrumDisplayForm QWidget
-        pyQt  = self.snk1.pyqwidget()
+        pyQt = self.snk1.qwidget()
 
         # Wrap the pointer as a PyQt SIP object
         # This can now be manipulated as a PyQt5.QtWidgets.QWidget
         pyWin = sip.wrapinstance(pyQt, QtWidgets.QWidget)
 
-        #pyWin.show()
+        # pyWin.show()
         self.main_box = dialog_box(pyWin, self.ctrl_win)
         self.main_box.show()
 
+
 if __name__ == "__main__":
-    tb = my_top_block();
+    tb = my_top_block()
     tb.start()
     tb.qapp.exec_()
     tb.stop()
