@@ -1,27 +1,13 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.12
 #
 # Copyright 2011,2012,2015 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 import sys
@@ -40,17 +26,20 @@ except ImportError:
     sys.stderr.write("Error: Program requires gr-analog.\n")
     sys.exit(1)
 
+
 class dialog_box(QtWidgets.QWidget):
     def __init__(self, display, control):
         QtWidgets.QWidget.__init__(self, None)
         self.setWindowTitle('PyQt Test GUI')
 
-        self.boxlayout = QtWidgets.QBoxLayout(QtWidgets.QBoxLayout.LeftToRight, self)
+        self.boxlayout = QtWidgets.QBoxLayout(
+            QtWidgets.QBoxLayout.LeftToRight, self)
         self.boxlayout.addWidget(display, 1)
         self.boxlayout.addWidget(control)
 
         self.resize(800, 500)
 
+
 class control_box(QtWidgets.QWidget):
     def __init__(self, parent=None):
         QtWidgets.QWidget.__init__(self, parent)
@@ -72,14 +61,12 @@ class control_box(QtWidgets.QWidget):
         self.layout.addRow("Signal 1 Amplitude:", self.amp1Edit)
         self.amp1Edit.editingFinished.connect(self.amp1EditText)
 
-
         # Control the second signal
         self.freq2Edit = QtWidgets.QLineEdit(self)
         self.freq2Edit.setMinimumWidth(100)
         self.layout.addRow("Signal 2 Frequency:", self.freq2Edit)
         self.freq2Edit.editingFinished.connect(self.freq2EditText)
 
-
         self.amp2Edit = QtWidgets.QLineEdit(self)
         self.amp2Edit.setMinimumWidth(100)
         self.layout.addRow("Signal 2 Amplitude:", self.amp2Edit)
@@ -115,7 +102,6 @@ class control_box(QtWidgets.QWidget):
         except ValueError:
             print("Bad amplitude value entered")
 
-
     def freq2EditText(self):
         try:
             newfreq = float(self.freq2Edit.text())
@@ -145,17 +131,17 @@ class my_top_block(gr.top_block):
 
         src1 = analog.sig_source_f(Rs, analog.GR_SIN_WAVE, f1, 0.1, 0)
         src2 = analog.sig_source_f(Rs, analog.GR_SIN_WAVE, f2, 0.1, 0)
-        src  = blocks.add_ff()
-        thr = blocks.throttle(gr.sizeof_float, 100*npts)
+        src = blocks.add_ff()
+        thr = blocks.throttle(gr.sizeof_float, 100 * npts)
         noise = analog.noise_source_f(analog.GR_GAUSSIAN, 0.001)
         add = blocks.add_ff()
         self.snk1 = qtgui.time_sink_f(npts, Rs,
-                                      "Complex Time Example", 3)
+                                      "Complex Time Example", 3, None)
 
-        self.connect(src1, (src,0))
-        self.connect(src2, (src,1))
-        self.connect(src, thr, (add,0))
-        self.connect(noise, (add,1))
+        self.connect(src1, (src, 0))
+        self.connect(src2, (src, 1))
+        self.connect(src, thr, (add, 0))
+        self.connect(noise, (add, 1))
         self.connect(add, self.snk1)
         self.connect(src1, (self.snk1, 1))
         self.connect(src2, (self.snk1, 2))
@@ -165,7 +151,7 @@ class my_top_block(gr.top_block):
         self.ctrl_win.attach_signal2(src2)
 
         # Get the reference pointer to the SpectrumDisplayForm QWidget
-        pyQt  = self.snk1.pyqwidget()
+        pyQt = self.snk1.qwidget()
 
         # Wrap the pointer as a PyQt SIP object
         # This can now be manipulated as a PyQt5.QtWidgets.QWidget
@@ -173,7 +159,7 @@ class my_top_block(gr.top_block):
 
         # Example of using signal/slot to set the title of a curve
         # FIXME: update for Qt5
-        #pyWin.setLineLabel.connect(pyWin.setLineLabel)
+        # pyWin.setLineLabel.connect(pyWin.setLineLabel)
         #pyWin.emit(QtCore.SIGNAL("setLineLabel(int, QString)"), 0, "Re{sum}")
         self.snk1.set_line_label(0, "Re{sum}")
         self.snk1.set_line_label(1, "src1")
@@ -182,12 +168,13 @@ class my_top_block(gr.top_block):
         # Can also set the color of a curve
         #self.snk1.set_color(5, "blue")
 
-        #pyWin.show()
+        # pyWin.show()
         self.main_box = dialog_box(pyWin, self.ctrl_win)
         self.main_box.show()
 
+
 if __name__ == "__main__":
-    tb = my_top_block();
+    tb = my_top_block()
     tb.start()
     tb.qapp.exec_()
     tb.stop()
