@@ -1,27 +1,13 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.12
 #
 # Copyright 2012,2013,2015 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
-# GNU Radio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3, or (at your option)
-# any later version.
+# SPDX-License-Identifier: GPL-3.0-or-later
 #
-# GNU Radio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNU Radio; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street,
-# Boston, MA 02110-1301, USA.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
 from gnuradio import gr
 from gnuradio import blocks
 from gnuradio import blocks
@@ -35,25 +21,28 @@ except ImportError:
     print("Error: Program requires PyQt5 and gr-qtgui.")
     sys.exit(1)
 
+
 class dialog_box(QtWidgets.QWidget):
     def __init__(self, display):
         QtWidgets.QWidget.__init__(self, None)
         self.setWindowTitle('PyQt Test GUI')
 
-        self.boxlayout = QtWidgets.QBoxLayout(QtWidgets.QBoxLayout.LeftToRight, self)
+        self.boxlayout = QtWidgets.QBoxLayout(
+            QtWidgets.QBoxLayout.LeftToRight, self)
         self.boxlayout.addWidget(display, 1)
 
         self.resize(800, 500)
 
+
 class my_top_block(gr.top_block):
     def __init__(self):
         gr.top_block.__init__(self)
 
         self.qapp = QtWidgets.QApplication(sys.argv)
 
-        data0  = 10*[0,] + 40*[1,0] + 10*[0,]
-        data0 += 10*[0,] + 40*[0,1] + 10*[0,]
-        data1 = 20*[0,] + [0,0,0,1,1,1,0,0,0,0] + 70*[0,]
+        data0 = 10 * [0, ] + 40 * [1, 0] + 10 * [0, ]
+        data0 += 10 * [0, ] + 40 * [0, 1] + 10 * [0, ]
+        data1 = 20 * [0, ] + [0, 0, 0, 1, 1, 1, 0, 0, 0, 0] + 70 * [0, ]
 
         # Adjust these to change the layout of the plot.
         # Can be set to fractions.
@@ -63,16 +52,16 @@ class my_top_block(gr.top_block):
         fs = 200
         src0 = blocks.vector_source_b(data0, True)
         src1 = blocks.vector_source_b(data1, True)
-        thr  = blocks.throttle(gr.sizeof_char, 50000)
+        thr = blocks.throttle(gr.sizeof_char, 50000)
         head = blocks.head(gr.sizeof_char, 10000000)
         self.snk1 = qtgui.time_raster_sink_b(fs, nrows, ncols, [], [],
-                                             "Time Raster Example", 2)
+                                             "Time Raster Example", 2, None)
 
         self.connect(src0, thr, (self.snk1, 0))
         self.connect(src1, (self.snk1, 1))
 
         # Get the reference pointer to the SpectrumDisplayForm QWidget
-        pyQt = self.snk1.pyqwidget()
+        pyQt = self.snk1.qwidget()
 
         # Wrap the pointer as a PyQt SIP object
         # This can now be manipulated as a PyQt5.QtWidgets.QWidget
@@ -81,8 +70,9 @@ class my_top_block(gr.top_block):
         self.main_box = dialog_box(pyWin)
         self.main_box.show()
 
+
 if __name__ == "__main__":
-    tb = my_top_block();
+    tb = my_top_block()
     tb.start()
     tb.qapp.exec_()
     tb.stop()
